@@ -1,4 +1,5 @@
 from asposewordscloud.models.requests.base_request_object import BaseRequestObject
+from asposewordscloud.models.requests.batch_request import BatchRequest
 from asposewordscloud.models.requests.accept_all_revisions_request import AcceptAllRevisionsRequest
 from asposewordscloud.models.requests.accept_all_revisions_online_request import AcceptAllRevisionsOnlineRequest
 from asposewordscloud.models.requests.append_document_request import AppendDocumentRequest
@@ -138,6 +139,7 @@ from asposewordscloud.models.requests.get_header_footer_of_section_online_reques
 from asposewordscloud.models.requests.get_header_footer_online_request import GetHeaderFooterOnlineRequest
 from asposewordscloud.models.requests.get_header_footers_request import GetHeaderFootersRequest
 from asposewordscloud.models.requests.get_header_footers_online_request import GetHeaderFootersOnlineRequest
+from asposewordscloud.models.requests.get_info_request import GetInfoRequest
 from asposewordscloud.models.requests.get_list_request import GetListRequest
 from asposewordscloud.models.requests.get_list_online_request import GetListOnlineRequest
 from asposewordscloud.models.requests.get_lists_request import GetListsRequest
