@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_border_request.py">
-#   Copyright (c) 2021 Aspose.Words for Cloud
+#   Copyright (c) 2022 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,10 +41,11 @@ class GetBorderRequest(BaseRequestObject):
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
-    :param password Password for opening an encrypted document.
+    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
+    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
     """
 
-    def __init__(self, name, border_type, node_path=None, folder=None, storage=None, load_encoding=None, password=None):
+    def __init__(self, name, border_type, node_path=None, folder=None, storage=None, load_encoding=None, password=None, encrypted_password=None):
         self.name = name
         self.border_type = border_type
         self.node_path = node_path
@@ -52,6 +53,7 @@ class GetBorderRequest(BaseRequestObject):
         self.storage = storage
         self.load_encoding = load_encoding
         self.password = password
+        self.encrypted_password = encrypted_password
 
     def create_http_request(self, api_client):
         # verify the required parameter 'name' is set
@@ -100,6 +102,8 @@ class GetBorderRequest(BaseRequestObject):
                 query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
         if self.password is not None:
                 query_params.append(('password', self.password))  # noqa: E501
+        if self.encrypted_password is not None:
+                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
 
         header_params = {}
 
