@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_custom_xml_part_online_request.py">
-#   Copyright (c) 2021 Aspose.Words for Cloud
+#   Copyright (c) 2022 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -38,14 +38,16 @@ class GetCustomXmlPartOnlineRequest(BaseRequestObject):
     :param document The document.
     :param custom_xml_part_index The index of the custom xml part. This index is the number of the entry in the collection of custom xml parts, not the ID of the part.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
-    :param password Password for opening an encrypted document.
+    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
+    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
     """
 
-    def __init__(self, document, custom_xml_part_index, load_encoding=None, password=None):
+    def __init__(self, document, custom_xml_part_index, load_encoding=None, password=None, encrypted_password=None):
         self.document = document
         self.custom_xml_part_index = custom_xml_part_index
         self.load_encoding = load_encoding
         self.password = password
+        self.encrypted_password = encrypted_password
 
     def create_http_request(self, api_client):
         # verify the required parameter 'document' is set
@@ -82,6 +84,8 @@ class GetCustomXmlPartOnlineRequest(BaseRequestObject):
                 query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
         if self.password is not None:
                 query_params.append(('password', self.password))  # noqa: E501
+        if self.encrypted_password is not None:
+                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
 
         header_params = {}
         # HTTP header `Content-Type`
