@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_document_statistics_online_request.py">
-#   Copyright (c) 2021 Aspose.Words for Cloud
+#   Copyright (c) 2022 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -37,16 +37,18 @@ class GetDocumentStatisticsOnlineRequest(BaseRequestObject):
     Initializes a new instance.
     :param document The document.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
-    :param password Password for opening an encrypted document.
+    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
+    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
     :param include_comments The flag indicating whether to include comments from the WordCount. The default value is "false".
     :param include_footnotes The flag indicating whether to include footnotes from the WordCount. The default value is "false".
     :param include_text_in_shapes The flag indicating whether to include shape's text from the WordCount. The default value is "false".
     """
 
-    def __init__(self, document, load_encoding=None, password=None, include_comments=None, include_footnotes=None, include_text_in_shapes=None):
+    def __init__(self, document, load_encoding=None, password=None, encrypted_password=None, include_comments=None, include_footnotes=None, include_text_in_shapes=None):
         self.document = document
         self.load_encoding = load_encoding
         self.password = password
+        self.encrypted_password = encrypted_password
         self.include_comments = include_comments
         self.include_footnotes = include_footnotes
         self.include_text_in_shapes = include_text_in_shapes
@@ -79,6 +81,8 @@ class GetDocumentStatisticsOnlineRequest(BaseRequestObject):
                 query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
         if self.password is not None:
                 query_params.append(('password', self.password))  # noqa: E501
+        if self.encrypted_password is not None:
+                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
         if self.include_comments is not None:
                 query_params.append(('includeComments', self.include_comments))  # noqa: E501
         if self.include_footnotes is not None:
