@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_header_footer_of_section_online_request.py">
-#   Copyright (c) 2021 Aspose.Words for Cloud
+#   Copyright (c) 2022 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -39,16 +39,18 @@ class GetHeaderFooterOfSectionOnlineRequest(BaseRequestObject):
     :param header_footer_index The index of the HeaderFooter object.
     :param section_index The index of the section.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
-    :param password Password for opening an encrypted document.
+    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
+    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
     :param filter_by_type The list of HeaderFooter types.
     """
 
-    def __init__(self, document, header_footer_index, section_index, load_encoding=None, password=None, filter_by_type=None):
+    def __init__(self, document, header_footer_index, section_index, load_encoding=None, password=None, encrypted_password=None, filter_by_type=None):
         self.document = document
         self.header_footer_index = header_footer_index
         self.section_index = section_index
         self.load_encoding = load_encoding
         self.password = password
+        self.encrypted_password = encrypted_password
         self.filter_by_type = filter_by_type
 
     def create_http_request(self, api_client):
@@ -93,6 +95,8 @@ class GetHeaderFooterOfSectionOnlineRequest(BaseRequestObject):
                 query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
         if self.password is not None:
                 query_params.append(('password', self.password))  # noqa: E501
+        if self.encrypted_password is not None:
+                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
         if self.filter_by_type is not None:
                 query_params.append(('filterByType', self.filter_by_type))  # noqa: E501
 
