@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="render_page_online_request.py">
-#   Copyright (c) 2021 Aspose.Words for Cloud
+#   Copyright (c) 2022 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -39,16 +39,18 @@ class RenderPageOnlineRequest(BaseRequestObject):
     :param page_index The index of the page.
     :param format The destination format.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
-    :param password Password for opening an encrypted document.
+    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
+    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
     :param fonts_location Folder in filestorage with custom fonts.
     """
 
-    def __init__(self, document, page_index, format, load_encoding=None, password=None, fonts_location=None):
+    def __init__(self, document, page_index, format, load_encoding=None, password=None, encrypted_password=None, fonts_location=None):
         self.document = document
         self.page_index = page_index
         self.format = format
         self.load_encoding = load_encoding
         self.password = password
+        self.encrypted_password = encrypted_password
         self.fonts_location = fonts_location
 
     def create_http_request(self, api_client):
@@ -91,6 +93,8 @@ class RenderPageOnlineRequest(BaseRequestObject):
                 query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
         if self.password is not None:
                 query_params.append(('password', self.password))  # noqa: E501
+        if self.encrypted_password is not None:
+                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
         if self.fonts_location is not None:
                 query_params.append(('fontsLocation', self.fonts_location))  # noqa: E501
 
