@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="save_as_range_online_request.py">
-#   Copyright (c) 2021 Aspose.Words for Cloud
+#   Copyright (c) 2022 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -40,16 +40,18 @@ class SaveAsRangeOnlineRequest(BaseRequestObject):
     :param document_parameters Parameters of a new document.
     :param range_end_identifier The range end identifier.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
-    :param password Password for opening an encrypted document.
+    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
+    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
     """
 
-    def __init__(self, document, range_start_identifier, document_parameters, range_end_identifier=None, load_encoding=None, password=None):
+    def __init__(self, document, range_start_identifier, document_parameters, range_end_identifier=None, load_encoding=None, password=None, encrypted_password=None):
         self.document = document
         self.range_start_identifier = range_start_identifier
         self.document_parameters = document_parameters
         self.range_end_identifier = range_end_identifier
         self.load_encoding = load_encoding
         self.password = password
+        self.encrypted_password = encrypted_password
 
     def create_http_request(self, api_client):
         # verify the required parameter 'document' is set
@@ -93,6 +95,8 @@ class SaveAsRangeOnlineRequest(BaseRequestObject):
                 query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
         if self.password is not None:
                 query_params.append(('password', self.password))  # noqa: E501
+        if self.encrypted_password is not None:
+                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
 
         header_params = {}
         # HTTP header `Content-Type`
